@@ -16,7 +16,7 @@ namespace ximc
 
 	public static class Version
 	{
-		public const String version = "2.14.17";
+		public const String version = "2.14.20";
 	};
 
 /*
@@ -540,8 +540,8 @@ namespace ximc
 	[StructLayout(LayoutKind.Sequential, CharSet=CharSet.Ansi)]
 	public struct password_settings_t
 	{
-		[MarshalAs(UnmanagedType.ByValArray, SizeConst = 20)]
-		public uint[] UserPassword;
+		[MarshalAs(UnmanagedType.ByValTStr, SizeConst = 21)]
+		public string UserPassword;
 	};
 
 	[StructLayout(LayoutKind.Sequential, CharSet=CharSet.Ansi)]
